@@ -43,7 +43,7 @@ halt all testing in the current file.
 
 =head1 SYNOPSIS
 
-    use Test2 qw/context/;
+    use Test2::API qw/context/;
     use Test2::Event::Bail;
 
     my $ctx = context();
